Package: irrCAC
Authors@R: person(given = c("Kilem", "L."),
                  family = "Gwet",
                  role = c("aut", "cre"),
                  email = "gwet@agreestat.com")
Version: 1.4
Date: 2026-04-26
Title: Computing the Extent of Agreement among Raters with
        Chance-Corrected Agreement Coefficient (CAC)
Description: Contains a series of R functions for calculating various chance-corrected agreement 
  coefficients (CAC) among 2 or more raters. Among the CAC coefficients covered are Cohen's kappa, Conger's kappa,
  Fleiss' kappa, Brennan-Prediger coefficient, Gwet's AC1/AC2 coefficients, and Krippendorff's alpha. Multiple
  sets of weights are proposed for computing weighted analyses. Also included in this package is Bangdiwala's B
  coefficient.
Depends: R (>= 3.5.0)
Encoding: UTF-8
Imports: dplyr, magrittr, tidyr, stringr, tibble
Language: en-US
LazyData: true
License: GPL (>= 2)
RoxygenNote: 7.3.3
Suggests: knitr, rmarkdown, spelling
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-26 19:33:14 UTC; GWET-ASUS-14
Author: Kilem L. Gwet [aut, cre]
Maintainer: Kilem L. Gwet <gwet@agreestat.com>
Repository: CRAN
Date/Publication: 2026-04-27 07:20:08 UTC
Built: R 4.5.2; ; 2026-04-27 09:38:02 UTC; unix
