# Generated by roxygen2: do not edit by hand

export(altman.bf)
export(bangdiwala.table)
export(bangdiwala2RR.fn)
export(bipolar.weights)
export(bp.coeff.dist)
export(bp.coeff.raw)
export(bp2.table)
export(circular.weights)
export(conger.kappa.raw)
export(fleiss.bf)
export(fleiss.kappa.dist)
export(fleiss.kappa.raw)
export(freq.supp.fn)
export(gwet.ac1.dist)
export(gwet.ac1.raw)
export(gwet.ac1.table)
export(identity.weights)
export(kappa2.table)
export(krippen.alpha.dist)
export(krippen.alpha.raw)
export(krippen2.table)
export(landis.koch.bf)
export(linear.weights)
export(long2wide.fn)
export(ordinal.weights)
export(pa.coeff.dist)
export(pa.coeff.raw)
export(pa2.table)
export(quadratic.weights)
export(radical.weights)
export(ratio.weights)
export(scott2.table)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,count)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,select)
importFrom(magrittr,"%>%")
importFrom(stats,na.omit)
importFrom(stats,pnorm)
importFrom(stats,pt)
importFrom(stats,qt)
importFrom(stats,setNames)
importFrom(stringr,str_trim)
importFrom(tibble,as_tibble)
importFrom(tidyr,drop_na)
importFrom(tidyr,pivot_wider)
