#' Ratings of 15 subjects from 4 raters  
#' 
#' This dataset contains raw ratings of 15 subjects produced by 4 raters named
#' as RaterA, RaterB, RaterC and RaterD. 
#' 
#' @format All 5 columns are of alphabetic type.
#'  \describe{
#'     \item{Gender}{Contains the subject's gender (M or F)}
#'     \item{RaterA}{Contains one of ratings a,b,c produced by RaterA}
#'     \item{RaterB}{Contains one of ratings a,b,c produced by RaterB}
#'     \item{RaterC}{Contains one of ratings a,b,c produced by RaterC}
#'     \item{RaterD}{Contains one of ratings a,b,c produced by RaterD}
#'  }   
#'  
#' @source K. Gwet, PhD.
#' 
"agreeCAC"