#' Rating Data from 4 Raters and 15 human Subjects, 9 of whom are female and 6 males.
#' 
#' This dataset contains data from a reliability experiment where 4 raters scored 15 units on a 3-point alphabetic scale 
#' based on the values a, b, and c.  
#' 
#' @format This dataset contains ratings obtained from an experiment where 4 raters classiffied 15 subjects into 3 
#' possible categories labeled as a, b, and c.
#' 
#' Note that only the the 4 last columns are to be used with the functions included in this package.  The first 
#' column only plays a descriptive role and is not to be used in any calculation.
#'  \describe{
#'     \item{Group}{This variable repsents the unit number.}
#'     \item{RaterA}{All ratings from rater 1}
#'     \item{RaterB}{All ratings from rater 2}
#'     \item{RaterC}{All ratings from rater 3}
#'     \item{RaterD}{All ratings from rater 4}
#'  }   
#'  
"cac.raw.gender"