utils::globalVariables(c("altman", "fleiss", "landis.koch"))
#' @importFrom tidyr drop_na pivot_wider
#' @importFrom dplyr count mutate select all_of
#' @importFrom stringr str_trim
#' @importFrom tibble as_tibble
#' @importFrom stats setNames