% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/weights.gen.r
\name{identity.weights}
\alias{identity.weights}
\title{Function for computing the Identity Weights}
\usage{
identity.weights(categ)
}
\arguments{
\item{categ}{A mandatory parameter representing the vector of all possible ratings.}
}
\value{
A square matrix of identity weights to be used for calculating the unweighted coefficients.
}
\description{
Function for computing the Identity Weights
}
